==> iTop-3.1.0-2-11973.zip: web/datamodels/2.x/itop-attachments/dictionaries/pl.dict.itop-attachments.php <==
<?php
/**
 * Copyright (C) 2013-2023 Combodo SARL
 *
 * This file is part of iTop.
 *
 * iTop is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * iTop is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 */
Dict::Add('PL PL', 'Polish', 'Polski', array(
	'Attachments:TabTitle_Count' => 'Załączniki (%1$d)',
	'Attachments:EmptyTabTitle' => 'Załączniki',
	'Attachments:FieldsetTitle' => 'Załączniki',
	'Attachments:DeleteBtn' => 'Usuń',
	'Attachments:History_File_Added' => 'Załącznik %1$s dodano.',
	'Attachments:History_File_Removed' => 'Załącznik %1$s usunięto.',
	'Attachments:AddAttachment' => 'Dodaj załącznik: ',
	'Attachments:UploadNotAllowedOnThisSystem' => 'Przesyłanie plików NIE jest dozwolone w tym systemie.',
	'Attachment:Max_Go' => '(Maksymalny rozmiar pliku: %1$s Go)',
	'Attachment:Max_Mo' => '(Maksymalny rozmiar pliku: %1$s Mo)',
	'Attachment:Max_Ko' => '(Maksymalny rozmiar pliku: %1$s Ko)',
	'Attachments:NoAttachment' => 'Brak załącznika. ',
	'Attachments:PreviewNotAvailable' => 'Podgląd nie jest dostępny dla tego typu załącznika.',
	'Attachments:Error:FileTooLarge' => 'Plik jest za duży do przesłania. %1$s',
	'Attachments:Error:UploadedFileEmpty' => 'Otrzymany plik jest pusty i nie można go załączyć.
Albo przesłałeś pusty plik,
lub zapytaj administratora '.ITOP_APPLICATION_SHORT.', czy dysk serwera '.ITOP_APPLICATION_SHORT.' jest pełny.',
	'Attachments:Render:Icons' => 'Wyświetlaj jako ikony',
	'Attachments:Render:Table' => 'Wyświetl jako listę',
	'UI:Attachments:DropYourFileHint' => 'Upuść pliki w dowolnym miejscu w tym obszarze',
));

//
// Class: Attachment
//

Dict::Add('PL PL', 'Polish', 'Polski', array(
	'Class:Attachment' => 'Załącznik',
	'Class:Attachment+' => '',
	'Class:Attachment/Attribute:expire' => 'Wygasa',
	'Class:Attachment/Attribute:expire+' => '',
	'Class:Attachment/Attribute:temp_id' => 'Id tymczasowy',
	'Class:Attachment/Attribute:temp_id+' => '',
	'Class:Attachment/Attribute:item_class' => 'Klasa pozycji',
	'Class:Attachment/Attribute:item_class+' => '',
	'Class:Attachment/Attribute:item_id' => 'Pozycja',
	'Class:Attachment/Attribute:item_id+' => '',
	'Class:Attachment/Attribute:item_org_id' => 'Organizacja pozycji',
	'Class:Attachment/Attribute:item_org_id+' => '',
	'Class:Attachment/Attribute:contents' => 'Zawartość',
	'Class:Attachment/Attribute:contents+' => '',
));


Dict::Add('PL PL', 'Polish', 'Polski', array(
	'Attachments:File:Thumbnail' => 'Ikona',
	'Attachments:File:Name' => 'Nazwa pliku',
	'Attachments:File:Date' => 'Data przesłania',
	'Attachments:File:Uploader' => 'Przesłany przez',
	'Attachments:File:Size' => 'Rozmiar',
	'Attachments:File:MimeType' => 'Typ',
	'Attachments:File:DownloadsCount' => 'Downloads~~',
));
//
// Class: Attachment
//

Dict::Add('PL PL', 'Polish', 'Polski', array(
	'Class:Attachment/Attribute:creation_date' => 'Data utworzenia',
	'Class:Attachment/Attribute:creation_date+' => '',
	'Class:Attachment/Attribute:user_id' => 'Id użytkownika',
	'Class:Attachment/Attribute:user_id+' => '',
	'Class:Attachment/Attribute:contact_id' => 'Id kontaktu',
	'Class:Attachment/Attribute:contact_id+' => '',
));

//
// Class: TriggerOnAttachmentDownload
//

Dict::Add('PL PL', 'Polish', 'Polski', array(
	'Class:TriggerOnAttachmentDownload' => 'Trigger (on object\'s attachment download)~~',
	'Class:TriggerOnAttachmentDownload+' => 'Trigger on object\'s attachment download of [a child class of] the given class~~',
));

==> iTop-3.2.2-1-17851.zip: web/datamodels/2.x/itop-attachments/dictionaries/pl.dict.itop-attachments.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('PL PL', 'Polish', 'Polski', array(
	'Attachments:TabTitle_Count' => 'Załączniki (%1$d)',
	'Attachments:EmptyTabTitle' => 'Załączniki',
	'Attachments:FieldsetTitle' => 'Załączniki',
	'Attachments:DeleteBtn' => 'Usuń',
	'Attachments:History_File_Added' => 'Załącznik %1$s dodano.',
	'Attachments:History_File_Removed' => 'Załącznik %1$s usunięto.',
	'Attachments:AddAttachment' => 'Dodaj załącznik: ',
	'Attachments:UploadNotAllowedOnThisSystem' => 'Przesyłanie plików NIE jest dozwolone w tym systemie.',
	'Attachment:Max_Go' => '(Maksymalny rozmiar pliku: %1$s Go)',
	'Attachment:Max_Mo' => '(Maksymalny rozmiar pliku: %1$s Mo)',
	'Attachment:Max_Ko' => '(Maksymalny rozmiar pliku: %1$s Ko)',
	'Attachments:NoAttachment' => 'Brak załącznika. ',
	'Attachments:PreviewNotAvailable' => 'Podgląd nie jest dostępny dla tego typu załącznika.',
	'Attachments:Error:FileTooLarge' => 'Plik jest za duży do przesłania. %1$s',
	'Attachments:Error:UploadedFileEmpty' => 'Otrzymany plik jest pusty i nie można go załączyć.
Albo przesłałeś pusty plik,
lub zapytaj administratora '.ITOP_APPLICATION_SHORT.', czy dysk serwera '.ITOP_APPLICATION_SHORT.' jest pełny.',
	'Attachments:Render:Icons' => 'Wyświetlaj jako ikony',
	'Attachments:Render:Table' => 'Wyświetl jako listę',
	'UI:Attachments:DropYourFileHint' => 'Upuść pliki w dowolnym miejscu w tym obszarze',
));

//
// Class: Attachment
//

Dict::Add('PL PL', 'Polish', 'Polski', array(
	'Class:Attachment' => 'Załącznik',
	'Class:Attachment+' => '',
	'Class:Attachment/Attribute:expire' => 'Wygasa',
	'Class:Attachment/Attribute:expire+' => '',
	'Class:Attachment/Attribute:temp_id' => 'Id tymczasowy',
	'Class:Attachment/Attribute:temp_id+' => '',
	'Class:Attachment/Attribute:item_class' => 'Klasa pozycji',
	'Class:Attachment/Attribute:item_class+' => '',
	'Class:Attachment/Attribute:item_id' => 'Pozycja',
	'Class:Attachment/Attribute:item_id+' => '',
	'Class:Attachment/Attribute:item_org_id' => 'Organizacja pozycji',
	'Class:Attachment/Attribute:item_org_id+' => '',
	'Class:Attachment/Attribute:contents' => 'Zawartość',
	'Class:Attachment/Attribute:contents+' => '',
));


Dict::Add('PL PL', 'Polish', 'Polski', array(
	'Attachments:File:Thumbnail' => 'Ikona',
	'Attachments:File:Name' => 'Nazwa pliku',
	'Attachments:File:Date' => 'Data przesłania',
	'Attachments:File:Uploader' => 'Przesłany przez',
	'Attachments:File:Size' => 'Rozmiar',
	'Attachments:File:MimeType' => 'Typ',
	'Attachments:File:DownloadsCount' => 'Pobrano',
));
//
// Class: Attachment
//

Dict::Add('PL PL', 'Polish', 'Polski', array(
	'Class:Attachment/Attribute:creation_date' => 'Data utworzenia',
	'Class:Attachment/Attribute:creation_date+' => '',
	'Class:Attachment/Attribute:user_id' => 'Id użytkownika',
	'Class:Attachment/Attribute:user_id+' => '',
	'Class:Attachment/Attribute:contact_id' => 'Id kontaktu',
	'Class:Attachment/Attribute:contact_id+' => '',
));

//
// Class: TriggerOnAttachmentDownload
//

Dict::Add('PL PL', 'Polish', 'Polski', array(
	'Class:TriggerOnAttachmentDownload' => 'Wyzwalacz (po pobraniu załącznika obiektu)',
	'Class:TriggerOnAttachmentDownload+' => 'Wyzwalacz po pobraniu załącznika obiektu [klasy podrzędnej] danej klasy',
));
